//
//  UITableView+CellHeight.m
//  AES_256
//
//  Created by skyzizhu on 2020/12/5.
//  Copyright © 2020 Bison. All rights reserved.
//

#import "UITableView+CellHeight.h"
#import <objc/runtime.h>

@implementation UITableView (CellHeight)

- (void)setAutoHeightDic:(NSMutableDictionary * _Nonnull)autoHeightDic
{
    objc_setAssociatedObject(self, @selector(autoHeightDic), autoHeightDic, OBJC_ASSOCIATION_RETAIN_NONATOMIC);
}
- (NSMutableDictionary *)autoHeightDic
{
    NSMutableDictionary *_autoHeightDic = objc_getAssociatedObject(self, @selector(autoHeightDic));
    if(_autoHeightDic == nil){
        _autoHeightDic = [NSMutableDictionary dictionary];
        objc_setAssociatedObject(self, @selector(autoHeightDic), _autoHeightDic, OBJC_ASSOCIATION_RETAIN_NONATOMIC);
    }
    return _autoHeightDic;
}
//缓存高度
- (void)cacheHeightWithCell:(UITableViewCell *)cell contentWidth:(CGFloat)width indexPath:(NSIndexPath *)indexPath;
{
    //设置字典key
    NSString *cacheKey = [self cacheKeyWithIndexPath:indexPath];
    //判断是否已经有缓存
    NSNumber *cacheHeight = [self.autoHeightDic objectForKey:cacheKey];
    if (cacheHeight) {
        return;
    }
    CGFloat height = [cell systemLayoutSizeFittingSize:CGSizeMake(width, 0) withHorizontalFittingPriority:UILayoutPriorityRequired verticalFittingPriority:UILayoutPriorityFittingSizeLevel].height;
    cacheHeight = [NSNumber numberWithFloat:height];
    [self.autoHeightDic setValue:cacheHeight forKey:cacheKey];
}

//获取高度
- (CGFloat)cacheHeightWithIndexPath:(NSIndexPath *)indexPath
{
    NSString *cacheKey = [self cacheKeyWithIndexPath:indexPath];
    NSNumber *cacheHeight = [self.autoHeightDic objectForKey:cacheKey];
    if (cacheHeight) {
        return [cacheHeight floatValue];
    }
    return UITableViewAutomaticDimension;
}
- (NSString *)cacheKeyWithIndexPath:(NSIndexPath *)indexPath
{
    return [NSString stringWithFormat:@"%ld-%ld", indexPath.section, indexPath.row];
}

@end
